
Tools for working with data.


```
cython
fastapi==0.74.1
required for web3?
requests>=2.11
python-multipart==0.0.5
pydantic[email,dotenv]==1.9.0

strawberry-graphql[debug-server,fastapi]
uvicorn==0.17.5
uvicorn[standard]

gunicorn==20.1.0
gunicorn[gthread]

python-jose[cryptography]==3.3.0
passlib[bcrypt]==1.7.4
pyserum
solana
web3==4.2.1
motor==2.5.1
redis==4.3.4
deep-translator==1.8.3
feedparser==6.0.8
Pillow==9.1.0
pytesseract==0.3.9
chardet==4.0.0
opencv-python==4.5.5.64
```